==> databricks_bundle-0.2.3-py3-none-any.whl: databricksbundle/spark/DatabricksConnectSessionFactory.py <==
from typing import Optional
from pyspark.sql.session import SparkSession
from pyspark.conf import SparkConf
from databricksbundle.spark.SparkSessionLazy import SparkSessionLazy

class DatabricksConnectSessionFactory:

    def __init__(
        self,
        address: str,
        token: str,
        clusterId: str,
        orgId: Optional[str],
        port: int,
        bindAddress: Optional[str],
        extraConfig: dict = None,
    ):
        self.__address = address
        self.__token = token
        self.__clusterId = clusterId
        self.__orgId = orgId
        self.__port = port
        self.__bindAddress = bindAddress
        self.__extraConfig = extraConfig or dict()

    def create(self) -> SparkSessionLazy:
        def createLazy():
            conf = SparkConf()
            conf.set('spark.databricks.service.address', self.__address)
            conf.set('spark.databricks.service.token', self.__token)
            conf.set('spark.databricks.service.clusterId', self.__clusterId)

            if self.__orgId is not None:
                conf.set('spark.databricks.service.orgId', self.__orgId)

            conf.set('spark.databricks.service.port', self.__port)

            if self.__bindAddress is not None:
                conf.set('spark.driver.bindAddress', self.__bindAddress)

            for k, v in self.__extraConfig.items():
                conf.set(k, v)

            return SparkSession.builder.config(conf=conf).getOrCreate()

        return SparkSessionLazy(createLazy)

==> databricks_bundle-0.3.3-py3-none-any.whl: databricksbundle/spark/DatabricksConnectSessionFactory.py <==
from typing import Optional, List
from pyspark.sql.session import SparkSession
from pyspark.conf import SparkConf
from databricksbundle.spark.SparkSessionLazy import SparkSessionLazy
from databricksbundle.spark.config.ConfiguratorInterface import ConfiguratorInterface

class DatabricksConnectSessionFactory:

    def __init__(
        self,
        address: str,
        token: str,
        clusterId: str,
        orgId: Optional[str],
        port: int,
        bindAddress: Optional[str],
        configurators: List[ConfiguratorInterface],
    ):
        self.__address = address
        self.__token = token
        self.__clusterId = clusterId
        self.__orgId = orgId
        self.__port = port
        self.__bindAddress = bindAddress
        self.__configurators = configurators

    def create(self) -> SparkSessionLazy:
        def createLazy():
            # Databricks Connect configuration must be set before calling getOrCreate()
            conf = SparkConf()
            conf.set('spark.databricks.service.address', self.__address)
            conf.set('spark.databricks.service.token', self.__token)
            conf.set('spark.databricks.service.clusterId', self.__clusterId)

            if self.__orgId is not None:
                conf.set('spark.databricks.service.orgId', self.__orgId)

            conf.set('spark.databricks.service.port', self.__port)

            if self.__bindAddress is not None:
                conf.set('spark.driver.bindAddress', self.__bindAddress)

            spark = SparkSession.builder.config(conf=conf).getOrCreate()

            for configurator in self.__configurators:
                configurator.configure(spark)

            return spark

        return SparkSessionLazy(createLazy)
